@@ -1,13 +1,10 @@
 import improviser.Ensembles.Bands as Bands
+import improviser.Progressions.Blues as Blues
 
 class Block:
 
 
-	progression = [	
-			(0, ["I", "I", "bV", "bII", "I", "IV", "bV", "bV"]),
-			(1, ["I", "bV", "V", "bII"]),
-			(2, 'R'),
-			]	
+	progression = Blues.jazzy_blues
 	
 	bpm = 200
 	iterations = 8
